/* -*- Mode: vala; tab-width: 4; intend-tabs-mode: t -*- */
/* alm
 *
 * Copyright (C) Seif Lotfy 2012 <seif@lotfy.com>
 * Copyright (C) Manish Sinha 2012 <manishsinha@ubuntu.com>
 *
alm is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 * 
 * alm is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.";
 */

using Gtk;
using Gee;

namespace Alm {

	public class HistoryWidget : Gtk.Box {

		private HashMap<string, string> past_records;
		private Box calendar_box;
		private ButtonBox button_box;
		ComboBoxText history_erase_kind;
		
		public HistoryWidget () {
			Object (orientation: Orientation.VERTICAL);
			this.spacing = 8;
			this.set_border_width(12);

			past_records = new HashMap<string, string>();
			past_records["hour"] = "the past hour";
			past_records["day"] = "the past day";
			past_records["week"] = "the past week";
			past_records["all"] = "all history";
			past_records["custom"] = "custom";

			this.set_up_ui ();
		}

		public void set_up_ui () {
			var top_box = new Box(Orientation.HORIZONTAL, 20);
			top_box.set_margin_top(30);
			this.pack_start(top_box, false, false);

			var label = new Label(null);
			label.set_markup("<b>Forget files activity:</b>");
			label.set_alignment(0, 0.5f);
			top_box.pack_start(label, false, false);

			var history_erase_kind = new ComboBoxText();
			foreach(string key in this.past_records.keys)
			{
				history_erase_kind.append(key, this.past_records[key]);
			}
			// Using anonymous function since using callback with 
			// on_history_combo_changed throws up a vala error:
			// Cannot convert from `Alm.HistoryWidget.on_history_combo_changed' to `Gtk.ComboBox.changed'
			history_erase_kind.changed.connect(() => {
				on_history_combo_changed(history_erase_kind);
			});
			top_box.pack_end(history_erase_kind, false, false);

			// Create Calendar
			this.calendar_box = new Box(Orientation.HORIZONTAL, 9);
			var start_box = new Box(Orientation.VERTICAL, 9);
			var end_box = new Box(Orientation.VERTICAL, 9);
			this.calendar_box.pack_start(start_box, false, false);
			this.calendar_box.pack_start(end_box, false, false);
			var start_label = new Label("From:");
			start_label.set_markup("<b>From:</b>");
			start_label.set_alignment(0, 0/5);
			start_box.pack_start(start_label, false, false);
			var end_label = new Label("To:");
			end_label.set_markup("<b>To:</b>");
			end_label.set_alignment(0, 0/5);
			end_box.pack_start(end_label, false, false);
			var start_calendar = new Calendar();
			start_box.pack_start(start_calendar, false, false);
			var end_calendar = new Calendar();
			end_box.pack_start(end_calendar, false, false);

			//this.pack_start(this.calendar_box, false, false);
			//this.remove(this.calendar_box);

			// Put Delete button
			this.button_box = new ButtonBox(Orientation.HORIZONTAL);
			this.button_box.layout_style = ButtonBoxStyle.START;
			this.pack_start(this.button_box, false, false);

			var del_button = new Button.from_stock(Stock.DELETE);
			button_box.pack_start(del_button, false, false);
		}

		private void insert_calendar () {
			//this.remove(this.button_box);
			//debug("Inserting calendar instance");
			//this.pack_end(this.calendar_box, false, false);
			//this.pack_start(this.button_box, false, false);
			if (this.calendar_box.get_parent() == null)
				this.pack_start(this.calendar_box, false, false, 18);
			this.calendar_box.show_all();
		}

		private void remove_calendar () {
			//debug("Removing calendar instance");
			//this.remove(this.calendar_box);
			this.calendar_box.hide();
		}

		private void on_history_combo_changed (ComboBoxText box) {
			debug(box.get_active_text());
			if(box.get_active_text() == "custom")
			{
				//debug("Inserting calendar");
				this.insert_calendar();
			}
			else
			{
				//debug("Removing calendar");
				this.remove_calendar();
			}
		}
	}
}
